@@ -16,8 +16,8 @@ class InvalidArgsError(Exception):
 
 _orekit._set_exception_types(JavaError, InvalidArgsError)
 
-VERSION = "9.2"
-CLASSPATH = [os.path.join(__dir__, "orekit-9.2.jar"), os.path.join(__dir__, "hipparchus-core-1.3.jar"), os.path.join(__dir__, "hipparchus-filtering-1.3.jar"), os.path.join(__dir__, "hipparchus-fitting-1.3.jar"), os.path.join(__dir__, "hipparchus-geometry-1.3.jar"), os.path.join(__dir__, "hipparchus-ode-1.3.jar"), os.path.join(__dir__, "hipparchus-optim-1.3.jar"), os.path.join(__dir__, "hipparchus-stat-1.3.jar")]
+VERSION = "9.3.1"
+CLASSPATH = [os.path.join(__dir__, "orekit-9.3.1.jar"), os.path.join(__dir__, "hipparchus-core-1.4.jar"), os.path.join(__dir__, "hipparchus-filtering-1.4.jar"), os.path.join(__dir__, "hipparchus-fitting-1.4.jar"), os.path.join(__dir__, "hipparchus-geometry-1.4.jar"), os.path.join(__dir__, "hipparchus-ode-1.4.jar"), os.path.join(__dir__, "hipparchus-optim-1.4.jar"), os.path.join(__dir__, "hipparchus-stat-1.4.jar")]
 CLASSPATH = os.pathsep.join(CLASSPATH)
 _orekit.CLASSPATH = CLASSPATH
 _orekit._set_function_self(_orekit.initVM, _orekit)
